import React, { HTMLProps } from "react";
import type { ClassName, PropsWithSpread } from "../../types";
export declare enum Label {
    Clear = "Clear search field",
    Search = "Search"
}
export type Props = PropsWithSpread<{
    /**
     * Whether autocomplete should be enabled for the search input.
     */
    autocomplete?: "on" | "off";
    /**
     * Optional classes to pass to the form element.
     */
    className?: ClassName;
    /**
     * Whether the input and buttons should be disabled.
     */
    disabled?: boolean;
    /**
     * Whether the input value will be controlled via external state.
     */
    externallyControlled?: boolean;
    /**
     * A function that will be called when the input value changes.
     */
    onChange?: (inputValue: string) => void;
    /**
     * A function that is called when the user clicks the search icon
     */
    onSearch?: () => void;
    /**
     * A function that is called when the user clicks the reset icon
     */
    onClear?: () => void;
    /**
     * A search input placeholder message.
     */
    placeholder?: string;
    /**
     * Whether the search input should receive focus after pressing the reset button
     */
    shouldRefocusAfterReset?: boolean;
    /**
     * A ref that is passed to the input element.
     */
    ref?: string;
    /**
     * The value of the search input when the state is externally controlled.
     */
    value?: string;
}, HTMLProps<HTMLInputElement>>;
declare const SearchBox: React.ForwardRefExoticComponent<Omit<Props, "ref"> & React.RefAttributes<HTMLInputElement>>;
export default SearchBox;
